@@ -5,7 +5,7 @@ Supported devices:
 - Corsair HXi (HX750i, HX850i, HX1000i and HX1200i)
 - Corsair RMi (RM650i, RM750i, RM850i and RM1000i)
 
-Copyright (C) 2019–2022  Jonas Malaco and contributors
+Copyright Jonas Malaco and contributors
 
 Port of corsaiRMi by notaz and realies.
 Copyright (c) notaz, 2016
@@ -76,7 +76,7 @@ class CorsairHidPsu(UsbHidDriver):
             'fpowin115': (0.00011552923724840388, 1.0111311876704099, 12.015296651918918),
             'fpowin230': ( 8.126644224872423e-05, 1.0176256272095185, 10.290640442373850),
         }),
-        (0x1b1c, 0x1c07, 'Corsair HX1000i', {
+        (0x1b1c, 0x1c07, 'Corsair HX1000i', {  # CP-9020074-NA
             'fpowin115': (9.48609754417109e-05,  1.0170509865269720, 11.619826520447452),
             'fpowin230': (9.649987544008507e-05, 1.0018241767296636, 12.759957859756842),
         }),
@@ -100,6 +100,16 @@ class CorsairHidPsu(UsbHidDriver):
             'fpowin115': (0.00010018433053123574, 1.0272313660072225, 14.092187353321624),
             'fpowin230': ( 8.600634771656125e-05, 1.0289245073649413, 13.701515390258626),
         }),
+        (0x1b1c, 0x1c1e, 'Corsair HX1000i (2022) (experimental)', {  # CP-9020214-NA
+            # FIXME does not accurately represent known efficiency curve at 2%–10% loads
+            'fpowin115': (0.12038623471806167, 0.9899868098825505, 0.01312560158286225),
+            'fpowin230': (0.08725695213088608, 1.0017598020558338, 0.009789546119565251),
+        }),
+        (0x1b1c, 0x1c1f, 'Corsair HX1500i (experimental)', {  # CP-9020215-NA
+            # FIXME does not accurately represent known efficiency curve at 2%–10% loads
+            'fpowin115': (0.099089523528618,   1.0125991459969408, 0.011978189078640221),
+            'fpowin230': (0.06951642350659733, 1.0183515407262729, 0.011039762908188666),
+        }),
     ]
 
     def __init__(self, *args, fpowin115=None, fpowin230=None, **kwargs):
